@@ -16,6 +16,12 @@ def proxy(argv=sys.argv):
   main = getattr(getattr(getattr(mod, 'scripts'), pcmd), 'main')
   return main(argv=argv)
 
+#------------------------------------------------------------------------------
+def pscheduler():
+  mod  = __import__('pyramid_scheduler.pscheduler')
+  main = getattr(getattr(mod, 'pscheduler'), 'main')
+  return main()
+
 #------------------------------------------------------------------------------
 # end of $Id$
 #------------------------------------------------------------------------------
